#! /bin/bash

#chmod 777 $(dirname $(readlink -f $0))

#拷贝目录结构，以供卸载时使用
function recursive_copy_file()
{
    dirlist=$(ls -a $1)
    for name in ${dirlist[*]}
do
    if [ "$name" == "." ] || [ "$name" == ".." ];then
        continue;
    fi

    if [ -f $1/$name ]; then
        # 如果是文件，并且$2不存在该文件，则直接copy
        if [ ! -f $2/$name ]; then
            touch $2/$name
        fi
    elif [ -d $1/$name ]; then
        # 如果是目录，并且$2不存在该目录，则先创建目录
        if [ ! -d $2/$name ]; then
            mkdir -p $2/$name
        fi
        # 递归拷贝
        recursive_copy_file $1/$name $2/$name
    fi
done
}

#语系
function get_current_locale()
{
    var=`locale | grep LC_CTYPE | cut -d '"' -f 2 | cut -d '.' -f 1`

    echo ${var}
}

#文件权限设置
function chmod_file()
{
    chmod 777 $(dirname $(readlink -f $0))

    find_file=`find /bin /usr/bin -type f -iname "file"`
    if [ "$find_file" == "" ];then
        chmod -R 777 *
        return
    fi

    #for origin_file in `find ./ -iname "*"`
    for origin_file in `find ./ -iname "*"|egrep -v "\.quarzone"`
    do
        exec_attribute=`file ${origin_file} | grep executable`
        if [ -n "${exec_attribute}" ];then
            chmod 555 ${origin_file}
        elif [ -d ${origin_file} ];then
            chmod 777 ${origin_file}
        else
            result=`echo $origin_file | grep ".sh"`
            if [ "$result" != "" ];then
                chmod 555 ${origin_file}
            else
                chmod 666 ${origin_file}
            fi
        fi
    done

    [ -f './antiy_userhelper' ] && chmod u+s "./antiy_userhelper"
}

function check_udev_so()
{
    origin_udev_file=`find /lib64 /usr/lib64 -type f | grep libudev.so`
    if [ "${origin_udev_file}" != "" ]; then
        ln -sf ${origin_udev_file} ./libs/libudev.so.0
    else
        origin_pcre_file=`find /lib64 /usr/lib64 -type f | grep libpcre.so`
        if [ "$origin_pcre_file" != "" ]; then
            ln -sf ${origin_pcre_file} ./libs/libudev.so.0
        fi
    fi
}

function install_system_menu()
{
    echo '[Desktop Entry]' 				>  /usr/share/applications/$1
    echo "Name= $2" 				>> /usr/share/applications/$1
    echo "Comment= $2" 				>> /usr/share/applications/$1
    echo "Exec= $3" 				>> /usr/share/applications/$1
    echo "Icon=`pwd`/icon.png"  			>> /usr/share/applications/$1
    echo "Type=Application"  			>> /usr/share/applications/$1
    echo 'Categories=System;Application;X-Fedora;' 	>> /usr/share/applications/$1
}

function get_current_desktop()
{
    var=`get_current_locale`

    zh="zh_CN"
    en="en_US"
    if [[ $var =~ $zh ]]
    then
        echo "桌面"
    elif [[ $var =~ $en ]]
    then
        echo "Desktop"
    fi
}

DBUS_NAME=org.polkit.antiy
INTERFACE=polkit.antiy.interface
BIN_NAME=antiy_polkit
BIN_PATH=/usr/bin/
WORKING_PATH=/opt/LinuxKPC/polkit/
POLICY=/usr/share/polkit-1/actions/${DBUS_NAME}.policy
CONF=/etc/dbus-1/system.d/${DBUS_NAME}.conf
SERVICE=/usr/share/dbus-1/system-services/${DBUS_NAME}.service

# polkit安装
function install_polkit
{
    policy_origin=${WORKING_PATH}${DBUS_NAME}.policy
    service_origin=${WORKING_PATH}${DBUS_NAME}.service
    conf_origin=${WORKING_PATH}${DBUS_NAME}.conf
    bin_origin=${WORKING_PATH}${BIN_NAME}
    [ -s ${policy_origin} ] && install -m644 ${policy_origin} ${POLICY}
    [ -s ${service_origin} ] && install -m644 ${service_origin} ${SERVICE}
    [ -s ${conf_origin} ] && install -m644  ${conf_origin} ${CONF}
    [ -s ${bin_origin} ] && install -m755 ${bin_origin} ${BIN_PATH}${BIN_NAME}
    echo "" >> ${SERVICE}                   # 追加，防止polkit第一次启动崩溃
}       

# polkit卸载
function uninstall_polkit
{
    rm -rf ${POLICY}
    rm -rf ${SERVICE}
    rm -rf ${CONF}
    rm -rf ${BIN_PATH}${BIN_NAME}
}

# pam安装
function install_pam
{
    if [ -f './pam/antiy_pam' -a -d '/etc/pam.d' ];then
        \cp './pam/antiy_pam' '/etc/pam.d'
    fi
}

# 拷贝key授权所需文件
function install_key_rules
{
    \cp './ini/antiy-longmai-key.rules' '/etc/udev/rules.d/'
    \cp './ini/antiy-haitai-key.rules' '/etc/udev/rules.d/'
}


# 火狐插件分发
function dispatch_addon()
{
    users=`awk -F ':' 'BEGIN {count=0;} {if (($3 >= 500 || $3 == 0) && $7 == "/bin/bash") {print $1}};' /etc/passwd`
    arr=($users)

    origin_path=`pwd`

    for user in ${arr[@]}
do
    if [ "$user" == "root" ];then
        pref=/$user/.mozilla/firefox/*.default/
    else
        pref=/home/$user/.mozilla/firefox/*.default/
    fi

    cd $pref
    ! [ -d ./extensions ] && mkdir extensions && chown ${user}:${user} ${pref}extensions

    cp -rf ${1} ${pref}extensions/
    chown -R ${user}:${user} ${pref}extensions/'antiy_web_protect@antiy.cn'
done

if [ -d "/usr/lib/firefox" ];then              #判断firefox库所在位置
    lib="/usr/lib/firefox"                 
elif [ -d "/usr/lib64/firefox" ];then
    lib="/usr/lib64/firefox"
fi

if [ x"$lib" != x ];then
    cp ${1}/config.js $lib                     #复制config.js至指定配置文件目录

    if [ -d "$lib/defaults/pref" ];then        #复制config-prefs.js至指定配置文件目录 
        cp ${1}/config-prefs.js $lib/defaults/pref/
    elif [ -d "$lib/defaults/preferences" ];then
        cp ${1}/config-prefs.js $lib/defaults/preferences
    fi
fi

cd ${origin_path}
}

# 雷鸟插件分发
function dispatch_mail_addon()
{
    users=`awk -F ':' 'BEGIN {count=0;} {if (($3 >= 500 || $3 == 0) && $7 == "/bin/bash") {print $1}};' /etc/passwd`
    arr=($users)

    origin_path=`pwd`

    cp antiy_web_protect@antiy.cn/chrome/content/avl_detect.so antiy_mail_protect@antiy.cn/chrome/content/

    for user in ${arr[@]}
do
    if [ "$user" == "root" ];then
        pref=/$user/.thunderbird/*.default/
    else
        pref=/home/$user/.thunderbird/*.default/
    fi

    cd $pref
    ! [ -d ./extensions ] && mkdir extensions && chown ${user}:${user} ${pref}extensions

    cp -rf ${1} ${pref}extensions/

    chown -R ${user}:${user} ${pref}extensions/'antiy_mail_protect@antiy.cn'

done

cd ${origin_path}
}

# 恢复扫描日志和防御日志
function recovery_log
{
    if [ -f "/usr/share/apsc/backup/report.db" ];then
        \cp -f /usr/share/apsc/backup/report.db /opt/LinuxKPC/ 
    fi 
}

#系统当前语系
current_locale=`get_current_locale`

cd $(dirname $(readlink -f $0))

exec &> ./log/install.log

recovery_log

#删除本地隔离区所有文件
rm -rf /opt/LinuxKPC/.quarzone/

#如果是suse系统则替换antiy_pam文件
if [ -f "/etc/issue" ];then
    cat /etc/issue | grep -i "suse" 
    if [ $? == "0" ];then
        rm -r ./pam/antiy_pam 
        mv ./pam/antiy_pam_suse ./pam/antiy_pam
    fi
fi

#赋予文件权限
chmod_file

rm -rf /opt/LinuxKPC/nactl.db
#检查设备目录
#check_udev_so

#刷新右键菜单
system_context=("gnome-open" "kde-open")

gcontext="gnome-open"

for scontext in ${system_context[@]}
do
    exec_path=`which $scontext`

    if [ ! -f "${exec_path}" ];then
        continue
    fi

    gcontext=$scontext

done


context_arr=("nautilus" "caja" "nemo")
for context in ${context_arr[@]}
do
    bin_path=`which $context`

    if [ ! -f "${bin_path}" ];then
        continue
    fi

    gcontext=$context

    so_path=`ldd $bin_path | grep $context | head -n 1 | awk '{ print $3}' `
    root_path=`dirname $so_path`

    if [ -d "$root_path/$context/extensions-1.0" ]; then
        ln -sf /opt/LinuxKPC/$context/libapsc_context_menu.so $root_path/$context/extensions-1.0/libapsc_context_menu.so
        chmod 755 $root_path/$context/extensions-1.0/libapsc_context_menu.so
    fi
    if [ -d "$root_path/$context/extensions-2.0" ]; then
        ln -sf /opt/LinuxKPC/$context/libapsc_context_menu.so $root_path/$context/extensions-2.0/libapsc_context_menu.so
        chmod 755 $root_path/$context/extensions-2.0/libapsc_context_menu.so
    fi
    if [ -d "$root_path/$context/extensions-3.0" ]; then
        ln -sf /opt/LinuxKPC/$context/libapsc_context_menu.so $root_path/$context/extensions-3.0/libapsc_context_menu.so
        chmod 755 $root_path/$context/extensions-3.0/libapsc_context_menu.so
    fi
done

if [ `arch` == "aarch64" ];then
    if [ -d '/usr/lib/aarch64-linux-gnu/caja/extensions-2.0' ]; then
        ln -sf /opt/LinuxKPC/caja/libapsc_context_menu.so /usr/lib/aarch64-linux-gnu/caja/extensions-2.0/libapsc_context_menu.so
        chmod 755 /usr/lib/aarch64-linux-gnu/caja/extensions-2.0/libapsc_context_menu.so 
    fi
fi

sed -i "/^context=/s/=.*/=${gcontext}/" KanOption.cfg
#注册开机项( root )
chmod +x /opt/LinuxKPC/auto_run.sh
/opt/LinuxKPC/auto_run.sh -regist

#注册系统开始菜单
lang="zh_CN"
if [[ ${current_locale} =~ $lang ]]
then
    install_system_menu kismain.desktop '安天智甲终端防御系统' "`pwd`/apsc_client_ui_desktop 0"
    install_system_menu kismain_un.desktop '安天智甲终端防御系统卸载' "`pwd`/uninstall_ui"
else
    install_system_menu kismain.desktop 'IEP Client' "`pwd`/apsc_client_ui_desktop 0"
    install_system_menu kismain_un.desktop 'IEP Client Uninstall' "`pwd`/uninstall_ui"
fi

#注册polkit
#install_polkit

#注册pam
install_pam

# 拷贝key授权所需文件
install_key_rules

#安装火狐插件
dispatch_addon "`pwd`/antiy_web_protect@antiy.cn"

#安装雷鸟插件
dispatch_mail_addon "`pwd`/antiy_mail_protect@antiy.cn"

if [ ! -f '/usr/share/apsc/software_license' ]; then
	! [ -d '/usr/share/apsc' ] && mkdir -p '/usr/share/apsc'
	cp './ini/software_license' '/usr/share/apsc/software_license'
fi

chmod 666 /usr/share/apsc/fd
chmod 666 /usr/share/apsc/software_license

if [ "$1" != "-update" ];then
    #在root用户注册桌面图标
    install -p -m 755 /usr/share/applications/kismain.desktop /root/桌面/
    install -p -m 755 /usr/share/applications/kismain.desktop /root/Desktop/

    #在普通用户注册桌面图标
    for i in `cat /etc/passwd | grep -v 'nologin' | awk -F: '$3>=500' | cut -f 6 -d :`
    do
        install -p -m 755 /usr/share/applications/kismain.desktop $i/桌面/
        install -p -m 755 /usr/share/applications/kismain.desktop $i/Desktop/
        user=`echo "$i" | cut -d '/' -f 3 `
        chown $user:$user $i/桌面/kismain.desktop
        chown $user:$user $i/Desktop/kismain.desktop
    done
fi

bname=`cat /tmp/kismain_install_cfg`
if [ "$1" != "-update" -a -n "${bname}" ];then       # 升级
    #生成初始化配置文件
    addressdata=`echo $bname |awk -F '(' '{print $2}' | awk -F ')' '{print $1}'`
    server=`echo $addressdata |awk -F '_' '{print $1}'`
    port=`echo $addressdata |awk -F '_' '{print $2}'`
    group=`echo $addressdata |awk -F '_' '{print $3}'`
    company=`echo $addressdata |awk -F '_' '{print $4}'`
    snid=`echo $addressdata |awk -F '_' '{print $5}'`
    cmdversion=`echo ${bname} | awk -F')-' '{print $2}' | awk -F'.' '{print $1}'`

    echo [url] > KanOptionV1.cfg
    echo main=$server:$port >> KanOptionV1.cfg
    echo [groupinfo] >> KanOptionV1.cfg
    echo id=$group >> KanOptionV1.cfg

    echo [companyinfo] >> KanOption.cfg
    echo id=$company >> KanOption.cfg
    echo [sn] >> KanOptionV1.cfg
    echo sn_id=$snid >> KanOptionV1.cfg
    if [ "${cmdversion}" = "cmd" ]; then
        echo '[scan]' >> KanOptionV2.cfg
        echo 'type=1' >> KanOptionV2.cfg
    elif [ "${cmdversion}" = "ker" ];then
        sed -i "/^user_monitor=/s/=.*/=0/" ini/IEPMonitor.cfg
    fi

    echo $server > update_svr
fi

#创建AVL日志及系统日志目录
! [ -d './log' ] && mkdir ./log
! [ -d './Log' ] && mkdir ./Log
! [ -d './.quarzone' ] && mkdir ./.quarzone

#chmod -R 777 *
chmod 777 /opt/LinuxKPC/.quarzone
#配置全局命令
ln -sf /opt/LinuxKPC/scanvirus /usr/bin/scanvirus
ln -sf /opt/LinuxKPC/nactl /usr/bin/nactl

#拷贝准入接口库
cp /opt/LinuxKPC/libs/AtInfoInterface.so /usr/local/lib/

#使用系统UI库，防止出现注销现象
if [ "$1" != "-update" ];then
	if [ -f "/usr/lib64/libQtCore.so.4" ];then
		systemCore=`ls -l /usr/lib64/libQtCore.so.4 | awk -F "->" '{ print $2 }' | awk '{ print $1 }'`
		\cp /usr/lib64/$systemCore /opt/LinuxKPC/libs/libQtCore.so.4
	fi

	if [ -f "/usr/lib64/libQtGui.so.4" ];then
		systemGui=`ls -l /usr/lib64/libQtGui.so.4 | awk -F "->" '{ print $2 }' | awk '{ print $1 }'`
		\cp /usr/lib64/$systemGui /opt/LinuxKPC/libs/libQtGui.so.4
	fi
fi

sync

#启动系统服务
( `pwd`/servicetools -start & )





