#!/bin/bash

VERSION='3.0'
DATE=`date +%F`

#内核模块名称以版本号命名
IEP_MODULE=iep$(uname -r | sed 's/\./_/g'| sed 's/-/_/g' | awk -F "_" '{ print $1,$2,$3,$4 }' | sed 's/ /_/g')
NACTL_MODULE=nactl$(uname -r | sed 's/\./_/g'| sed 's/-/_/g' | awk -F "_" '{ print $1,$2,$3,$4 }' | sed 's/ /_/g')

#设置环境变量
function set_env()
{
    insmod_path=`find /sbin /bin /usr/bin /usr/sbin -type f -iname "insmod"`
    rmmod_path=`find /sbin /bin /usr/bin /usr/sbin -type f -iname "rmmod"`

    insmod_env=`dirname $insmod_path`
    rmmod_env=`dirname $insmod_path`

    if [ "$insmod_env"x = "$rmmod_env"x ]; then 
	path=$insmod_env
    else
	path=$insmod_env:$rmmod_env
    fi

    export PATH=$PATH:$path
}

#加载网络防护模块
function insmod_nactl()
{
    if [ -d ./ko ];then
	rmmod $NACTL_MODULE

	module_path=./ko/$NACTL_MODULE.ko
	insmod $module_path
    fi
}

#加载主动防御模块
function insmod_iep()
{
    sys_call_table=`cat /proc/kallsyms | grep "\bR sys_call_table\b" | awk '{print $1}'`

    if [ x"$sys_call_table" = x ];then
	sys_call_table=`cat /boot/System.map-$(uname -r) | grep "\bsys_call_table\b" | awk '{print $1}'`
    fi

    if [ -d ./ko ];then
	rmmod $IEP_MODULE

	module_path=./ko/$IEP_MODULE.ko
	insmod $module_path sys_call_tab=0x"$sys_call_table"
    else
	rmmod $IEP_MODULE
	insmod monitor.ko
    fi
}

#卸载网络防护模块
function rmmod_nactl()
{
    rmmod $NACTL_MODULE
}

#卸载主动防御模块
function rmmod_iep()
{
    if [ -d ./ko ];then
	rmmod $IEP_MODULE
    else
	rmmod monitor
    fi
}

function version() {
    echo "主动防御 For Linux (v.$VERSION)"
}

set_env

function usage() {
cat << EOF
usage: $0 [options]

-i    加载主动防御内核模块
-r    卸载主动防御内核模块
-a    加载网络防御内核模块
-d    卸载网络防御内核模块
-v    查看版本信息
-h    显示帮助信息

EOF
}

if [ $# -eq 0 ];then
    usage
    exit 1
elif [ $# -gt 1 ];then
    tput setaf 1;echo -e "\033[1mERROR: Invalid Option Provided!\033[0m";tput sgr0
    echo
    usage
    exit 1
fi

while getopts ":iardvh" OPTION; do
    case $OPTION in
	i)
	insmod_iep
	exit $?
	;;
	a)
	insmod_nactl
	exit $?
	;;
	r)
	rmmod_iep	
	;;
	d)
	rmmod_nactl
	;;
	v)
	version
	exit 0
	;;
	h)
	usage
	exit 0
	;;
	?)
	tput setaf 1;echo -e "\033[1mERROR: Invalid Option Provided!\033[0m";tput sgr0
	echo
	usage
	exit 1
	;;
    esac
done
