#! /bin/bash
cd $(dirname $(readlink -f $0))

exec 2> /dev/null

function get_current_desktop()
{
	var=`locale | grep LC_CTYPE | cut -d '"' -f 2 | cut -d '.' -f 1`

	if [ "$var" == "zh_CN" ]; then
		echo "桌面"
	elif [ "$var" == "en_US" ]; then
		echo "Desktop"
	fi
}

DBUS_NAME=org.polkit.antiy
INTERFACE=polkit.antiy.interface

POLICY=/usr/share/polkit-1/actions/${DBUS_NAME}.policy
CONF=/etc/dbus-1/system.d/${DBUS_NAME}.conf
SERVICE=/usr/share/dbus-1/system-services/${DBUS_NAME}.service

BIN_NAME=antiy_polkit
BIN_PATH=/usr/bin/
WORKING_PATH=/opt/LinuxKPC/polkit/

# 删除目录/文件
remove_path()
{
    path=$1
    if [ -d $path ]; then
        if [ `ls -A $dir|wc -l` != 0 ]; then
            #echo "rm -rf $path/* ."
            rm -rf $path/*
        fi
    else
        if [ -f $path ]; then
            #echo "rm -rf $path."
            rm -rf $path
        #else
        #    echo "$path not exist!"
        fi
    fi
}

# polkit安装
function install_polkit
{
        install -m644 ${WORKING_PATH}${DBUS_NAME}.policy ${POLICY}
        install -m644 ${WORKING_PATH}${DBUS_NAME}.service ${SERVICE}
        install -m644 ${WORKING_PATH}${DBUS_NAME}.conf ${CONF}
	install -m644 ${WORKING_PATH}${BIN_NAME} ${BIN_PATH}${BIN_NAME}
}

# polkit卸载
function uninstall_polkit
{
        remove_path ${POLICY}
        remove_path ${SERVICE}
        remove_path ${CONF}
        remove_path ${BIN_PATH}${BIN_NAME}
}

function uninstall_addon()
{
        users=`awk -F ':' 'BEGIN {count=0;} {if (($3 >= 500 || $3 == 0) && $7 == "/bin/bash") {print $1}};' /etc/passwd`
        arr=($users)

        origin_path=`pwd`

        for user in ${arr[@]}
        do
                if [ "$user" == "root" ];then
                        pref=/$user/.mozilla/firefox/*.default/
                else
                        pref=/home/$user/.mozilla/firefox/*.default/
                fi

                cd $pref
                [ -d ${pref}/extensions/$1 ] && remove_path $pref/extensions/$1
        done

        cd ${origin_path}
}

function remove_recfile()
{
	[ -d /usr/share/apsc/fd/ ] && rm -rf /usr/share/apsc/fd/ >/dev/null 2>&1 #清除fd文件

	[ -d /tmp/ ] && rm -rf /tmp/*.pid >/dev/null 2>&1 #清除tmp下的pid文件

	#按清除用户主目录下的fd文件
	users=`awk -F ':' 'BEGIN {count=0;} {if (($3 >= 500 || $3 == 0) && $7 == "/bin/bash") {print $1}};' /etc/passwd`
	arr=($users)

	for user in ${arr[@]}
	do
		if [ "$user" == "root" ];then
			pref=/$user/.kismain
		else
			pref=/home/$user/.kismain
		fi

		[ -d $pref ]&& rm -rf $pref/.*.pid >/dev/null 2>&1
	done
}

function uninstall_key_rules
{
    rm  -rf '/etc/udev/rules.d/antiy-longmai-key.rules'
    rm  -rf '/etc/udev/rules.d/antiy-haitai-key.rules'
}

function back_up_log
{
    ! [ -d '/usr/share/apsc/backup' ] && mkdir -p '/usr/share/apsc/backup'
    \cp -f /opt/LinuxKPC/report.db /usr/share/apsc/backup/
}

#向通信程序发送卸载通知
./send_uninstall

#等待2秒
sleep 2

#停止服务
`pwd`/servicetools -preuninstall

sleep 2

#删除服务启动项
sed -i '/kismain/d' /etc/rc.d/rc.local
#chkconfig --del kismain
remove_path /etc/init.d/kismain

#删除托盘启动项
sed -i '/apsc_client_ui/d' /etc/profile

#删除右键菜单库文件
remove_path /usr/lib64/nautilus/extensions-1.0/libapsc_context_menu.so

#向通信程序发送卸载通知
#pkill -USR1 kisspyer

[ -f '/dev/shm/VirusCacheData.bin' ] && remove_path '/dev/shm/VirusCacheData.bin'
#rmmod "monitor"

#备份扫描日志和防御日志
back_up_log

#删除文件
remove_path `pwd`/
rm -rf `pwd`/.quarzone/

#touch /opt/LinuxKPC/ini/software_license
if [ ! -d /opt/LinuxKPC/.quarzone/ ]; then
	mkdir /opt/LinuxKPC/.quarzone/
fi
touch /opt/LinuxKPC/.quarzone/.gitkeep

#删除各个用户的安全状态文件 ~/.safe_status
find /home -name ".safe_status" | xargs rm -rf {};
remove_path /root/.safe_status

#卸载桌面图标、软连接、开始菜单的快捷方式
remove_path /usr/share/applications/kismain.desktop
remove_path /usr/share/applications/kismain_un.desktop

#卸载桌面启动
remove_path /etc/xdg/autostart/kismain.desktop 

# 此方法删除桌面图标，在polkit中，继承的语系环境为POSIX，有产生问题
#rm -rf /root/`get_current_desktop`/kismain.desktop

[ -e /root/桌面/kismain.desktop ] && remove_path /root/桌面/kismain.desktop
[ -e /root/Desktop/kismain.desktop ] && remove_path /root/Desktop/kismain.desktop

find /home -name "kismain.desktop" | xargs rm -rf {}

#polkit卸载
killall antiy_polkit
uninstall_polkit
# 插件卸载
uninstall_addon "antiy_web_protect@antiy.cn"

#删除准入接口¬
rm -rf /usr/local/lib/AtInfoInterface.so

#清除fd文件和pid文件
remove_recfile
uninstall_key_rules

exit 0

