#!/bin/bash

CVE201811235=(
	'2.17.0'
	'2.16.3'
	'2.16.0'
	'2.15.1'
	'2.15.0'
	'2.14.3'
	'2.14.2'
	'2.14.1'
	'2.14.0'
	'2.13.6'
	'2.13.5'
	'2.13.4'
	'2.13.3'
	'2.13.2'
	'2.13.1'
	'2.13.0'
	  
)


param=$1
package_name=$2

if [ "$package_name" = "" ]; then
        #echo "-1"
        exit -1   
fi

CVEID=`eval echo '"''$'{"$param"[@]}'"'`


check_package() {

    running_version=$1         
    vulnerable_versions=$2   
    
    for tested_package in ${vulnerable_versions[@]}; do
        if [[ "$running_version" == *"$tested_package"* ]]; then
            echo "$running_version"
            break
        fi
    done
}   
    
    

    
if [[ "${BASH_SOURCE[0]}" == "$0" ]]; then

system_type=`sed -n 5p ./ini/version | cut -d "=" -f2`
#echo $system_type

if [ "$system_type" = "debian" ]; then
	        
    running_version=$( dpkg -l $package_name )
else

    running_version=$( rpm -qa $package_name )
fi
   
# echo $running_version
    
      
    # package checks
    vulnerable_package=$( check_package "$running_version" "${CVEID[@]}" )
    
    
    if [[ "$vulnerable_package" ]]; then
        package_exploitable="true"
    fi
    
    
    # Debug prints
    if [[ "$debug" ]]; then
        echo "running_version = *$running_version*"
        echo "vulnerable_package = *$vulnerable_package*"
        echo "applied_kpatch = *$applied_kpatch*"
        echo "package_exploitable = *$package_exploitable*"
        echo
    fi

    # Results
# echo -e "Detected running package is '${BOLD}$running_version${RESET}'."
#   echo

    if [[ "$vulnerable_package" ]]; then
        
        echo -e "${RED}This 'package' version is vulnerable.${RESET}" >/dev/null
       
    else
        echo -e "${GREEN}This 'package' version is not vulnerable.${RESET}" >/dev/null
    fi

    if [[ "$package_exploitable" ]]; then
        exit 1  # Both exploitable
    else
        exit 0
    fi
fi

